← Back to team overview

launchpad-reviewers team mailing list archive

[Merge] lp:~smartboyhw/launchpad/bug-1137716-fix into lp:launchpad

 

Howard Chan has proposed merging lp:~smartboyhw/launchpad/bug-1137716-fix into lp:launchpad.

Requested reviews:
  Launchpad code reviewers (launchpad-reviewers)
Related bugs:
  Bug #1137716 in Launchpad itself: "Code page suggests using invalid bzr flag --use-existing"
  https://bugs.launchpad.net/launchpad/+bug/1137716

For more details, see:
https://code.launchpad.net/~smartboyhw/launchpad/bug-1137716-fix/+merge/152557

To fix Bug 1137716.
-- 
https://code.launchpad.net/~smartboyhw/launchpad/bug-1137716-fix/+merge/152557
Your team Launchpad code reviewers is requested to review the proposed merge of lp:~smartboyhw/launchpad/bug-1137716-fix into lp:launchpad.
=== modified file 'lib/lp/code/browser/tests/test_branch.py'
--- lib/lp/code/stories/branches/xx-upload-directions.txt	2012-08-16 13:54:54 +0000
+++ lib/lp/code/stories/branches/xx-upload-directions.txt	2013-03-09 11:43:23 +0000
@@ -76,7 +76,7 @@
     >>> instructions = find_tag_by_id(content, 'upload-directions')
     >>> print extract_text(instructions)
     Update this branch:
-    bzr push --use-existing lp://dev/~name12/gnome-terminal/pushed
+    bzr push --use-existing-dir lp://dev/~name12/gnome-terminal/pushed
 
 
 == SSH key directions ==
@@ -183,7 +183,7 @@
     >>> instructions = find_tag_by_id(content, 'upload-directions')
     >>> print extract_text(instructions)
     Update this branch:
-    bzr push --use-existing
+    bzr push --use-existing-dir
     lp://dev/~landscape-developers/gnome-terminal/pushed
 
 

=== modified file 'lib/lp/code/templates/branch-management.pt'
--- lib/lp/code/templates/branch-management.pt	2012-03-10 15:08:09 +0000
+++ lib/lp/code/templates/branch-management.pt	2013-03-09 11:43:23 +0000
@@ -48,7 +48,7 @@
               <tt class="command">
               bzr push
               <tal:use-existing condition="view/is_empty_directory">
-              --use-existing
+              --use-existing-dir
               </tal:use-existing>
               <span class="branch-url" tal:content="context/bzr_identity" />
               </tt>


Follow ups
--- lib/lp/code/browser/tests/test_branch.py	2013-02-28 03:48:21 +0000
+++ lib/lp/code/browser/tests/test_branch.py	2013-03-09 11:43:23 +0000
@@ -228,16 +228,16 @@
         self.assertFalse(view.is_empty_directory)
 
     def test_empty_directories_use_existing(self):
         # Push example should include --use-existing for empty directories.
         branch = self.factory.makeBranch(owner=self.user)
         text = self.getMainText(branch)
-        self.assertIn('push\n--use-existing', text)
+        self.assertIn('push\n--use-existing-dir', text)
         with person_logged_in(self.user):
             # Make it look as though the branch has been pushed.
             branch.branchChanged(
                 None, None, ControlFormat.BZR_METADIR_1, None, None)
         text = self.getMainText(branch)
-        self.assertNotIn('push\n--use-existing', text)
+        self.assertNotIn('push\n--use-existing-dir', text)
 
     def test_user_can_upload(self):
         # A user can upload if they have edit permissions.
@@ -228,16 +228,16 @@
 
     def test_empty_directories_use_existing(self):
-        # Push example should include --use-existing for empty directories.
+        # Push example should include --use-existing-dir for empty directories.
         branch = self.factory.makeBranch(owner=self.user)
         text = self.getMainText(branch)

=== modified file 'lib/lp/code/stories/branches/xx-upload-directions.txt'